@@ -27,7 +27,9 @@ fn patch_git_invalid_dependency() {
     let patch_bin =
         cargo_dir().join(format!("cargo-patch{}", env::consts::EXE_SUFFIX));
     p.process(&patch_bin)
-    .with_stderr_contains("Error: failed to get `asdf` as a dependency of package [..]")
+        .with_stderr_contains(
+            "Error: failed to get `asdf` as a dependency of package [..]",
+        )
         .with_status(1)
         .run();
 }
